# Changelog

<a name="0.0.38"></a>
## 0.0.38 (2023-10-16)

### Changed

- ⬆️ Drop support of python &lt; 3.10 [[7ad1507](https://github.com/Freed-Wu/translate-shell/commit/7ad1507117cfa799ce7ebe69d307423b6618832c)]
- ♻️ Change Translation to a Namespace [[3d907c3](https://github.com/Freed-Wu/translate-shell/commit/3d907c3e6c0850c7654a328b9b0c9d876c68ee7d)]
- 🚚 Rename misc.py to section.py [[1aea450](https://github.com/Freed-Wu/translate-shell/commit/1aea450bc2fee68b21943c30c7ddefc773f7851c)]
- 🚚 Rename Translation to Translations [[7fad1a2](https://github.com/Freed-Wu/translate-shell/commit/7fad1a2e63dfeb0b565edaa208ef4cf97ff67b93)]

### Fixed

- 🐛 Fix language server [[5686142](https://github.com/Freed-Wu/translate-shell/commit/56861428fc023a49d01b71ec68b07a166a056df3)]
- 🐛 replace Namespace.__dict__ by OrderDict [[085ca3e](https://github.com/Freed-Wu/translate-shell/commit/085ca3edf119b13b02b728313e316b5b4922c1d2)]

### Miscellaneous

- 📝 Update README.md [[5f21685](https://github.com/Freed-Wu/translate-shell/commit/5f21685b234678ec4d6e8cb79abb5ad8fad8be4d)]
- 🏷️ Remove symlink [[3b51f31](https://github.com/Freed-Wu/translate-shell/commit/3b51f318523bc2cbc7c6bc0200889c87c68e2d93)]


<a name="0.0.37"></a>
## 0.0.37 (2023-09-09)

### Added

- ✨ Add a tool for REPL [[bf64f9a](https://github.com/Freed-Wu/translate-shell/commit/bf64f9ad2a2cf993c02a3a81c896bb112c8877c5)]
- ➕ Use sphinxcontrib-autofile for documents [[126469f](https://github.com/Freed-Wu/translate-shell/commit/126469f258220a5a512f85d799cb5d47c7ae2cb0)]
- ➕ Use sphinxcontrib-requirements-txt for documents [[9b246b1](https://github.com/Freed-Wu/translate-shell/commit/9b246b1715551ba863f1fd0563d00f2f96518379)]

### Miscellaneous

- 📝 Use sphinx.ext.todo [[d8e6aae](https://github.com/Freed-Wu/translate-shell/commit/d8e6aae779cdf793962b9c1edee6ba98cbff1c81)]


<a name="0.0.36"></a>
## 0.0.36 (2023-08-31)

### Changed

- ⚡ Short prompt output length [[98a46b9](https://github.com/Freed-Wu/translate-shell/commit/98a46b9dca7d62d074aa556eb37aca1c7c65a668)]

### Fixed

- 🚑 Fix wrong API call [[7f8ace0](https://github.com/Freed-Wu/translate-shell/commit/7f8ace0a01ac859cd37defaf3d687e6b1b43b6ae)]


<a name="0.0.35"></a>
## 0.0.35 (2023-08-29)

### Fixed

- 🚑 Fix append of translate_shell.tools.generate_prompt [[757de81](https://github.com/Freed-Wu/translate-shell/commit/757de81c424ff1f2c7321f87974d8f60895c4b45)]


<a name="0.0.34"></a>
## 0.0.34 (2023-08-29)

### Added

- ✨ Add tool: generate_prompt [[a49c2bd](https://github.com/Freed-Wu/translate-shell/commit/a49c2bd1f94d042c4be0747426ab71518227ea63)]

### Fixed

- 🐛 Fix [#33](https://github.com/Freed-Wu/translate-shell/issues/33) [[abf0d2e](https://github.com/Freed-Wu/translate-shell/commit/abf0d2e8fed570de21547f66cd456ddf7ed9dc1d)]


<a name="0.0.33"></a>
## 0.0.33 (2023-08-06)

### Fixed

- 🐛 Fix speaker for a sentence [[b24592e](https://github.com/Freed-Wu/translate-shell/commit/b24592e3a080f770ceafc2726407513414d03578)]


<a name="0.0.32"></a>
## 0.0.32 (2023-07-23)

### Fixed

- 🚑 Fix default of --options [[987342e](https://github.com/Freed-Wu/translate-shell/commit/987342e9238c74f4e223dc9dfa928d213a3fb5ed)]


<a name="0.0.31"></a>
## 0.0.31 (2023-07-20)

### Added

- ➕ Add tomli [[e2616de](https://github.com/Freed-Wu/translate-shell/commit/e2616de9d6e0aa00fa9a6b2ca09d4110b9b55c7d)]
- 👷‍♂️ Add deploy-nur CD [[42251be](https://github.com/Freed-Wu/translate-shell/commit/42251be90713cfe83771ca83070bdca511275669)]


<a name="0.0.30"></a>
## 0.0.30 (2023-07-16)

### Added

- ✨ Add option to github action [[531a1ab](https://github.com/Freed-Wu/translate-shell/commit/531a1abdd2edf7b2fd31a1015db061db2d9ae71d)]
- ✨ Support openai, llama [[e63717d](https://github.com/Freed-Wu/translate-shell/commit/e63717d05134acba15ea1ca4c9fb624af369fd76)]
- ✨ Support ecdict [[3f87fb0](https://github.com/Freed-Wu/translate-shell/commit/3f87fb0710cc5703c0ce48f5bee8969444f1839f)]
- ✨ Add force to action.yml [[515ca71](https://github.com/Freed-Wu/translate-shell/commit/515ca717b9374df5806107230cbcd492d39c152c)]
- ✅ Improve test [[a835275](https://github.com/Freed-Wu/translate-shell/commit/a835275ec0ed91ce378192f01b9e62349aa3d35e)]

### Breaking changes

- 💥 Add options to translate() [[f6f17b0](https://github.com/Freed-Wu/translate-shell/commit/f6f17b06671bc73157f62fbacaf236628ce5f5bc)]

### Miscellaneous

- 🧑‍💻 Add Translator.convert_langs() [[0c91cfc](https://github.com/Freed-Wu/translate-shell/commit/0c91cfcc51c2586fce8c4d573bdb761b565a9b1b)]
- 🧑‍💻 Add translate_shell.tools.po [[346d08f](https://github.com/Freed-Wu/translate-shell/commit/346d08f4aba31120978c33c0de403e21c3f89138)]
- 📦 Fix flake.nix [[46c6d3b](https://github.com/Freed-Wu/translate-shell/commit/46c6d3b2e2b609d7e5c1ae6a7bfe0bb4f73a66d1)]


<a name="0.0.29"></a>
## 0.0.29 (2023-07-05)

### Added

- ✅ Fix pytest [[5b7f2dc](https://github.com/Freed-Wu/translate-shell/commit/5b7f2dcb5a3f7e9619f9513dc2868f791f0d2b57)]
- ✨ Add NixOS icon [[a128fdd](https://github.com/Freed-Wu/translate-shell/commit/a128fdddc7c2664401ebecedf62de8a12103a302)]
- ✨ Support LSP [[7bd1a73](https://github.com/Freed-Wu/translate-shell/commit/7bd1a73c45edc3f2f61d59e7d7799da21b4209e9)]

### Fixed

- 💚 Add if to skip AUR CI/CD to fasten [[66e3571](https://github.com/Freed-Wu/translate-shell/commit/66e3571ac6b77ea071e0b66c693a464427434583)]

### Miscellaneous

- 📝 Update scripts/generate-requirements.md.pl [[ae6cdf2](https://github.com/Freed-Wu/translate-shell/commit/ae6cdf217b86b1caad3f9c6550ee6165b71c05dc)]
- 🧑‍💻 Add skipcq [[f044b82](https://github.com/Freed-Wu/translate-shell/commit/f044b82476be07e1f289856f373eb4a49d920c1c)]


<a name="0.0.28"></a>
## 0.0.28 (2023-06-15)

### Fixed

- 🐛 Fix stardict dictionary path [[c40ef47](https://github.com/Freed-Wu/translate-shell/commit/c40ef47a0cb198fed26bf1679d18feb99c4a9d13)]

### Miscellaneous

- 📝 Update install.md [[01c2e26](https://github.com/Freed-Wu/translate-shell/commit/01c2e2614c88a5985bbe62de0892ec3ebc15ed4a)]
- 🧑‍💻 Improve action [[42585cd](https://github.com/Freed-Wu/translate-shell/commit/42585cdd8513256c56d40e63d779620c8c3a3304)]


<a name="0.0.27"></a>
## 0.0.27 (2023-05-31)

### Added

- 👷‍♂️ Add action.yml [[9a4e522](https://github.com/Freed-Wu/translate-shell/commit/9a4e522201457160f750a039167c285e99c8244f)]

### Fixed

- 💚 Move AUR CD to the last to avoid incomplete downloading [[25d2277](https://github.com/Freed-Wu/translate-shell/commit/25d22779ad414e5591f6d6a5845bb58ae724e5ba)]


<a name="0.0.26"></a>
## 0.0.26 (2023-05-25)

### Changed

- 👽 Adapt pynotifier &gt;&#x3D; 0.5.0 [[0b6f5b0](https://github.com/Freed-Wu/translate-shell/commit/0b6f5b085d26405d153a6d7a22541885301f37f3)]


<a name="0.0.25"></a>
## 0.0.25 (2023-05-24)

### Changed

- 👽 Delete some deprecated nerd font symbols [[0452f57](https://github.com/Freed-Wu/translate-shell/commit/0452f577f13df18b279692bf57a7e44c968ff11a)]

### Miscellaneous

- 📦 Add meta.mainProgram [[9dc9b07](https://github.com/Freed-Wu/translate-shell/commit/9dc9b076d51431bc469f16fe69e40562a9f94b38)]


<a name="0.0.24"></a>
## 0.0.24 (2023-04-20)

### Fixed

- 🐛 Fix a typo [[abc0c3a](https://github.com/Freed-Wu/translate-shell/commit/abc0c3ad435c90fd17e44d30439a7674029e21a7)]


<a name="0.0.23"></a>
## 0.0.23 (2023-04-11)

### Added

- 👷‍♂️ Add update-aur-package [[96f810c](https://github.com/Freed-Wu/translate-shell/commit/96f810c7dc7649542d24d2a1e5450914a3a5e6a4)]

### Fixed

- 🐛 Fix wrong title of CITATION.cff [[ece5322](https://github.com/Freed-Wu/translate-shell/commit/ece532288b34cea44cee4e883627f71aa49e81a9)]

### Miscellaneous

- 📦 Fix nix build [[f8b7c7a](https://github.com/Freed-Wu/translate-shell/commit/f8b7c7a5e04145419dedd97b6b971df600df7804)]
- 📦 Fix version of setuptools-generate [[1f135fc](https://github.com/Freed-Wu/translate-shell/commit/1f135fc3439fe5714a981dde67dcee1908353e6f)]


<a name="0.0.22"></a>
## 0.0.22 (2023-04-06)

### Removed

- 🔥 Remove autotools, use tool.setuptools.data-files [[e1f78ad](https://github.com/Freed-Wu/translate-shell/commit/e1f78ad2e15a78968c996ecbae4c8e86c2cee899)]

### Miscellaneous

- 📦 Fix sdist [[1f980b9](https://github.com/Freed-Wu/translate-shell/commit/1f980b932e74cbaf9e804dd6c5e622bcb60478c9)]


<a name="0.0.21"></a>
## 0.0.21 (2023-04-05)

### Miscellaneous

- 📦 Fix missing DESTDIR [[c8dbee0](https://github.com/Freed-Wu/translate-shell/commit/c8dbee006459a0d57c8b646cdc57e1bcd756a7a2)]
- 📦 Add make check [[c74ece9](https://github.com/Freed-Wu/translate-shell/commit/c74ece9b63e9d47a9eb1055d497aea3512ba7880)]


<a name="0.0.20"></a>
## 0.0.20 (2023-04-05)

### Fixed

- 🐛 Fix [#28](https://github.com/Freed-Wu/translate-shell/issues/28): empty clipper [[4777c3c](https://github.com/Freed-Wu/translate-shell/commit/4777c3ca00832bb13f626b1245fd4b4a2d47a043)]
- 🐛 Fix a typo of pyproject.toml [[52ea35e](https://github.com/Freed-Wu/translate-shell/commit/52ea35e196d573b4602b019bc0412120ec3a9e0e)]

### Miscellaneous

- 📦 Support autotools [[4141a7b](https://github.com/Freed-Wu/translate-shell/commit/4141a7b02c4be0d84ca47247d1573ccece3865e7)]
- 📝 Add some sphinx extensions [[189dca1](https://github.com/Freed-Wu/translate-shell/commit/189dca10eca6503f36b2d01f15dae8fc05adf3a9)]
- 📝 Add some translators to document [[80438bb](https://github.com/Freed-Wu/translate-shell/commit/80438bb0c7e706696e0094c9e170508b76a73d9b)]
- 📦 Support nix [[404448d](https://github.com/Freed-Wu/translate-shell/commit/404448dd0c226fdfc41b9cc470d36caf1b2b5aa8)]
- 📝 Support nix [[570bd79](https://github.com/Freed-Wu/translate-shell/commit/570bd79217e0104a9d342cc1d7f1ef2aa1d7b74d)]


<a name="0.0.19"></a>
## 0.0.19 (2023-03-29)

### Added

- 👷‍♂️ Update .pre-commit-config.yaml [[2827464](https://github.com/Freed-Wu/translate-shell/commit/28274648a080cadd28483f745079d69f67f49dec)]

### Fixed

- 🐛 Fix [#27](https://github.com/Freed-Wu/translate-shell/issues/27): wrong encoding in windows [[ab105ce](https://github.com/Freed-Wu/translate-shell/commit/ab105ce3b008459342f89896ae8f947560b30b92)]

### Miscellaneous

- 📝 Add translation for zh_CN [[064658b](https://github.com/Freed-Wu/translate-shell/commit/064658bee23240cc5dd1df169c045081d3458b96)]


<a name="0.0.18"></a>
## 0.0.18 (2023-03-21)

### Added

- ✨ Support wakatime [[4ec84c7](https://github.com/Freed-Wu/translate-shell/commit/4ec84c7607c2d080f633473f1983beb011296164)]
- 👷‍♂️ Add pre-commit-shfmt, perltidy [[7224d16](https://github.com/Freed-Wu/translate-shell/commit/7224d16702c663c51d845fa856798b31b6826ff7)]
- 👷‍♂️ Add dependabot [[14c2ebc](https://github.com/Freed-Wu/translate-shell/commit/14c2ebcb48b0c126358b67b5fde061ea7308d5c2)]

### Removed

- ➖ Remove some dev dependencies [[e11b522](https://github.com/Freed-Wu/translate-shell/commit/e11b5222d2a7f33d5981cced2d14f169c984686e)]

### Fixed

- 💚 Remove pre-commit from github action [[7ffba6b](https://github.com/Freed-Wu/translate-shell/commit/7ffba6b730e9ca91487686e5c325df0b97058a04)]
- 💚 Disable latex docs [[1adf3f2](https://github.com/Freed-Wu/translate-shell/commit/1adf3f2e385d42fee610341910f86e1f257da6a6)]
- 💚 Fix github action about windows [[41fe26c](https://github.com/Freed-Wu/translate-shell/commit/41fe26c7723faef4e8ab5edc1f2b6918dd02f305)]

### Miscellaneous

- 📝 Fix invalid URLs in docs [[8a71704](https://github.com/Freed-Wu/translate-shell/commit/8a7170462ca8dd7fd385d57181801263d0b1259b)]


<a name="0.0.17"></a>
## 0.0.17 (2023-03-16)

### Added

- ✨ Support customizing notifying [[a8aed28](https://github.com/Freed-Wu/translate-shell/commit/a8aed280defbae568e950debd95e33cfbdae332c)]

### Miscellaneous

- 📝 Add prompt in config.md [[019be95](https://github.com/Freed-Wu/translate-shell/commit/019be953ab982d59edb97af7e23c2a0af4966248)]


<a name="0.0.16"></a>
## 0.0.16 (2023-03-04)

### Removed

- 🔥 Remove Makefile [[c3a835c](https://github.com/Freed-Wu/translate-shell/commit/c3a835c2d1b5416c97e82ebfbdef4630db9a3d6e)]


<a name="0.0.15"></a>
## 0.0.15 (2023-03-04)

### Changed

- 🎨 Remove unused keys in pyproject.toml [[16ad0fb](https://github.com/Freed-Wu/translate-shell/commit/16ad0fbb6ba48294af909b5cde9af411b356db72)]

### Miscellaneous

- 📝 Add Changelog [[9e94297](https://github.com/Freed-Wu/translate-shell/commit/9e9429742a509e165dab80e9f489b669c575eb8d)]


<a name="0.0.14"></a>
## 0.0.14 (2023-03-03)

### Changed

- 🚚 Change template extension to jinja2 [[939d116](https://github.com/Freed-Wu/translate-shell/commit/939d116ef755c9ba745d0b9df7edb84e40393ccd)]
- 🎨 Little update for module import [[fadc959](https://github.com/Freed-Wu/translate-shell/commit/fadc9594c26d88655e26cdd65dcd8179e8f2d668)]

### Fixed

- 🐛 Fix icon path to respect FHS [[1736b86](https://github.com/Freed-Wu/translate-shell/commit/1736b86dfefbdf25981c924971dbb9946079accd)]


<a name="0.0.13"></a>
## 0.0.13 (2023-02-27)

### Changed

- 🎨 Improve code of powerlevel10k sections [[44de5d1](https://github.com/Freed-Wu/translate-shell/commit/44de5d10b40bbf7d5eab0301d7964a540863b3a1)]


<a name="0.0.12"></a>
## 0.0.12 (2023-02-21)

### Added

- 👷‍♂️ Update pre-commit [[a187d7a](https://github.com/Freed-Wu/translate-shell/commit/a187d7ad64a7e83d7b3fbfb2a6eb21501300776d)]

### Fixed

- 🚑 Fix [#24](https://github.com/Freed-Wu/translate-shell/issues/24), google&#x27;s explains [[983d944](https://github.com/Freed-Wu/translate-shell/commit/983d944b5b26f203312a98d035fae98cdde4f3cd)]

### Miscellaneous

- 📝 Add deepsource badge [[878f5d6](https://github.com/Freed-Wu/translate-shell/commit/878f5d62c1f943b8313204c69cfffc30762ae294)]


<a name="0.0.11"></a>
## 0.0.11 (2023-01-23)

### Fixed

- 🚑 Fix str() [[d687703](https://github.com/Freed-Wu/translate-shell/commit/d687703fd8cd6d0fb17a0e6ab3f8b0db6fe49ff5)]


<a name="0.0.10"></a>
## 0.0.10 (2023-01-23)

### Added

- ✅ Fix test [[9a10f7a](https://github.com/Freed-Wu/translate-shell/commit/9a10f7a2e174e8202635b656c30a12b54d8d3561)]
- ✅ Fix pyright [[cb99ed6](https://github.com/Freed-Wu/translate-shell/commit/cb99ed6de7e94bd8ec8252d43b8f23092b8fbc6a)]
- ✅ Skip a audit [[2a61a1d](https://github.com/Freed-Wu/translate-shell/commit/2a61a1d985717fe6e636d230fac7038ae06d0518)]
- ✅ Update test_patterns [[92d8284](https://github.com/Freed-Wu/translate-shell/commit/92d8284d16f571e2ec5d675c656958ae4aac6543)]
- 👷‍♂️ Add .deepsource.toml [[d2e1133](https://github.com/Freed-Wu/translate-shell/commit/d2e1133baad8c06c70f338dd2316e09495b8ddaa)]
- 👷‍♂️ Update pre-commit [[5cf8a6c](https://github.com/Freed-Wu/translate-shell/commit/5cf8a6cbf614f5d3d85e1a327b07009c2be19b1b)]

### Changed

- 🎨 Remove unused module [[d9f2a42](https://github.com/Freed-Wu/translate-shell/commit/d9f2a42e3e6425f13dbe2249b4b4098eeeeb2657)]
- 🎨 Fix many anti patterns [[b9d1a8c](https://github.com/Freed-Wu/translate-shell/commit/b9d1a8cb88b2dfb421ed729bdbae85c839075373)]
- ♻️ Remove some &#x27;global&#x27;s [[5d77268](https://github.com/Freed-Wu/translate-shell/commit/5d77268ea6fb4952e0259987a79e8571ec730d39)]
- ♻️ Rewrite get_youdaozhiyun_app_info() [[e9c0c75](https://github.com/Freed-Wu/translate-shell/commit/e9c0c753448dce5c6045bb2ce37358432bb9c5ed)]
- 🎨 Fix [#19](https://github.com/Freed-Wu/translate-shell/issues/19): module imports itself [[9c8fc98](https://github.com/Freed-Wu/translate-shell/commit/9c8fc98b39ca4f60374d61e9feb2e424fae2522f)]
- 🎨 Fix [#17](https://github.com/Freed-Wu/translate-shell/issues/17) about redefinition [[ff058af](https://github.com/Freed-Wu/translate-shell/commit/ff058af1dc90300b8f4e399fd9a3e5732915ed1c)]
- 🎨 Fix [#16](https://github.com/Freed-Wu/translate-shell/issues/16), add __all__ [[34fddc4](https://github.com/Freed-Wu/translate-shell/commit/34fddc415674e386646cb2a07497630ce120e566)]
- 🎨 Fix [#14](https://github.com/Freed-Wu/translate-shell/issues/14), fix inconsistent return [[6e4a057](https://github.com/Freed-Wu/translate-shell/commit/6e4a05701e4d24b1f2ad5b014ae11bc840a68d2a)]
- 🎨 Fix [#12](https://github.com/Freed-Wu/translate-shell/issues/12), format templates/metainfo.py [[ca75799](https://github.com/Freed-Wu/translate-shell/commit/ca75799a34ed1ed5c68c2f0ccbb6ba161182e05e)]

### Fixed

- 🐛 Fix wrong calls of static methods [[4689bb6](https://github.com/Freed-Wu/translate-shell/commit/4689bb6bdf7f1ba5e290e0fd5338432e1c40f3f4)]
- 🐛 Fix [#20](https://github.com/Freed-Wu/translate-shell/issues/20): Exceptions are overlapping [[c559b5e](https://github.com/Freed-Wu/translate-shell/commit/c559b5eae6bf077659f547a1dba9106fcda16391)]
- 🐛 Use &#x60;sys.exit()&#x60; calls [[ddd4359](https://github.com/Freed-Wu/translate-shell/commit/ddd43593ec105ffc978b007f8225b239f94409b5)]
- 🐛 Fix [#9](https://github.com/Freed-Wu/translate-shell/issues/9), remove str.format [[21f12f3](https://github.com/Freed-Wu/translate-shell/commit/21f12f347b528c8b8f76408fbb242909946629ae)]
- 🐛 Change eval-sh to eval-bash [[34bbce4](https://github.com/Freed-Wu/translate-shell/commit/34bbce4acb9c691d95dda7e4cc796d736a216c2b)]
- 💚 Only upload when CI machine is linux [[6dc0820](https://github.com/Freed-Wu/translate-shell/commit/6dc082016d8df6de0eacf93a81191b47ddc58224)]

### Miscellaneous

-  Format code with black [[8d0bb18](https://github.com/Freed-Wu/translate-shell/commit/8d0bb182cab7394ffe68496f2a326a7650897d7e)]
-  Set &#x60;check&#x60; flag to &#x60;True&#x60; [[41fe780](https://github.com/Freed-Wu/translate-shell/commit/41fe7808d4d1b09103180488d51a7bec372f7488)]
-  Fix dangerous default argument [[044c9bc](https://github.com/Freed-Wu/translate-shell/commit/044c9bcf5a04cc4484d55fa82393610d1161796a)]
-  Remove unnecessary &#x60;pass&#x60; [[b0ddb44](https://github.com/Freed-Wu/translate-shell/commit/b0ddb447198ef5e0fb25112026b4325e6457bc2a)]
-  Refactor unnecessary &#x60;else&#x60; / &#x60;elif&#x60; when &#x60;if&#x60; block has a &#x60;return&#x60; statement [[f788363](https://github.com/Freed-Wu/translate-shell/commit/f7883636ca0e6e149e92ddc11e5138b37e9a645f)]
-  Change methods not using its bound instance to staticmethods [[7c6c971](https://github.com/Freed-Wu/translate-shell/commit/7c6c97141078ce7ade190587e4754bbc1fa8dfd0)]
-  Format code with black [[df47aa9](https://github.com/Freed-Wu/translate-shell/commit/df47aa90f3b426b8f54ec38944990900f9766ff7)]
-  Pass string format arguments as logging method parameters [[98a6536](https://github.com/Freed-Wu/translate-shell/commit/98a65364cb35cc367ee7cbb4fb2ba2511296ffe4)]
- 📝 Fix todo.md/acknowledge.md [[8cb3378](https://github.com/Freed-Wu/translate-shell/commit/8cb3378cad84511b3d25d6e6080f1e10446f5e53)]
- 📝 Add globstar [[1fc1a51](https://github.com/Freed-Wu/translate-shell/commit/1fc1a517eee1e24dcacb2e007a075d5e3254414a)]
- 🧑‍💻 Add executable mode for convenient [[333aedc](https://github.com/Freed-Wu/translate-shell/commit/333aedc20b3baa11b326cd61dd7241a0a6a8af85)]


<a name="0.0.9"></a>
## 0.0.9 (2023-01-09)

### Miscellaneous

- 📝 Update readline.md [[61140ee](https://github.com/Freed-Wu/translate-shell/commit/61140ee0889452f4d261de56fbf79073eff93255)]


<a name="0.0.8"></a>
## 0.0.8 (2023-01-08)

### Changed

- 💄 Add readline tab complete function [[3cf533e](https://github.com/Freed-Wu/translate-shell/commit/3cf533e55c1ac72035de952d7bdee29ee6c545e5)]

### Miscellaneous

- 📝 Fix wrong document build path [[3afec95](https://github.com/Freed-Wu/translate-shell/commit/3afec95a8cd2385602d508ca402f8d9602d7f35e)]


<a name="0.0.7"></a>
## 0.0.7 (2022-12-14)

### Removed

- ➖ Remove build-misc from github actions [[f1dd72a](https://github.com/Freed-Wu/translate-shell/commit/f1dd72abc3c80a80dabf6485e3a90c3187a73eef)]


<a name="0.0.6"></a>
## 0.0.6 (2022-12-08)

### Removed

- 🔥 Remove invalid code about SHELL [[fbdfcbe](https://github.com/Freed-Wu/translate-shell/commit/fbdfcbe03809546253b4e31f08255342acde311d)]


<a name="0.0.5"></a>
## 0.0.5 (2022-12-07)

### Added

- ✨ Support Android [[0189a77](https://github.com/Freed-Wu/translate-shell/commit/0189a77a5c075475e22dd96f177b88ef1a226668)]


<a name="0.0.4"></a>
## 0.0.4 (2022-12-05)

### Added

- ✨ Support GUI [[888007e](https://github.com/Freed-Wu/translate-shell/commit/888007ea4f7aa01a9aeebf8f71bffd770d6d2e07)]


<a name="0.0.3"></a>
## 0.0.3 (2022-12-04)

### Changed

- ♻️ Rewrite clipboard [[3c94cd9](https://github.com/Freed-Wu/translate-shell/commit/3c94cd9d817d7f0664b520dafcda76bf0df199ae)]


<a name="0.0.2"></a>
## 0.0.2 (2022-12-03)

### Fixed

- 🐛 Fix missing files [[8ea4fbb](https://github.com/Freed-Wu/translate-shell/commit/8ea4fbbfe3d9fc8576a8cbc8148c5e72edb26f2e)]


<a name="0.0.1"></a>
## 0.0.1 (2022-12-03)

### Added

- 🎉 Initial [[d410c5d](https://github.com/Freed-Wu/translate-shell/commit/d410c5dce390205f23113831f8f4eef9e0b8423c)]
